import setuptools
setuptools.setup(
    name='ftdz_vip',
    version='1.0.0',
    author='bob',
    author_email='56141537@qq.com',
    description='',
    long_description_content_type="""text/markdown""",
    url='https://www.github.com/',
    packages=['ftdz_vip'],
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ]
)
